@@ -48,7 +48,8 @@ Condition = R6Class("Condition",
 
     #' @description
     #' Helper for print outputs.
-    format = function() {
+    #' @param ... (ignored).
+    format = function(...) {
       sprintf("<%s:%s>", class(self)[1L], self$type)
     },
 
